@@ -5,9 +5,12 @@ from nltk.corpus.reader.wordnet import Synset
 from nltk.corpus import wordnet
 from nltk.corpus import stopwords
 from nltk.corpus.reader.wordnet import ADJ, ADJ_SAT, ADV, NOUN, VERB
+from numpy.random import uniform
+from numpy.random import seed
 
 from ffast.preprocessor import PreprocessingPipeline
 
+seed(0)
 def create_vocabulary() -> Generator[Tuple[str,Synset],None,None]:
     for meaning in wordnet.all_synsets():
         for lemma in meaning.lemmas():
@@ -25,6 +28,9 @@ SIZE_STOPWORDS = len(STOPWORDS)
 SIZE_WORDNET = len(VOCABULARY)
 SIZE_SEMANTIC_VECTOR = SIZE_STOPWORDS + SIZE_WORDNET 
 SIZE_WORD_VECTOR = SIZE_SEMANTIC_VECTOR + SIZE_METAPHONES 
+SIZE_SENTENCE_VECTOR = 2*(5*SIZE_WORD_VECTOR)
+SIZE_PROJECTION = 100
+RANDOM_MATRIX = uniform(size=(SIZE_PROJECTION,SIZE_SENTENCE_VECTOR))
 
 class WordNet(Enum):
     SKIP = "skip"
